@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,8 +32,7 @@
 
 #include <QDir>
 
-K_PLUGIN_FACTORY_WITH_JSON(ThunderbirdImporterFactory, "thunderbirdimporter.json", registerPlugin<ThunderbirdImportData>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(ThunderbirdImportData, "thunderbirdimporter.json")
 
 ThunderbirdImportData::ThunderbirdImportData(QObject *parent, const QList<QVariant> &)
     : LibImportWizard::AbstractImporter(parent)
